@@ -248,7 +248,8 @@ class VariableOsInstallX11Composite(VideoVariable):
 
     def get(self):
         """On/off composite"""
-        defaultCompositeOn = ("nvidia","intel","fglrx","nouveau","radeon")
+        defaultCompositeOn = ("nvidia","intel","fglrx",
+            "nouveau","radeon", "default")
         composite = getValueFromCmdLine("calculate",5)
         videodrv = getValueFromCmdLine("calculate",4)
         if videodrv != "auto":
